//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraArgsValidationException](index.md)/[args](args.md)

# args

[common]\
val [args](args.md): [HoraArgs](../-hora-args/index.md)
